<?php
/**
 * Plugin Name:       Maintainer
 * Plugin URI:        https://matterwp.com/plugins/maintainer
 * Description:       Fast, simple WordPress maintenance mode and coming soon pages.
 * Version:           1.1.2
 * Author:            MatterWP
 * Author URI:        https://matterwp.com
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       maintainer
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

// Include the Init class
// This class is responsible for initializing the plugin.
use Maintainer\Core\Init;
use Maintainer\Core\Activator;
use Maintainer\Core\Deactivator;
use Maintainer\Core\Internalization;
use MatterWP\WPSubscriptionManager\SubscriptionManagerFactory;

// Include the Composer autoload file.
// This file is responsible for loading all the classes and dependencies.
require __DIR__ . '/vendor/autoload.php';

/**
 * Global Definitions.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'MAINTAINER_NAME', 'maintainer' );
define( 'MAINTAINER_VERSION', '1.1.2' );
define( 'MAINTAINER_FILE', __FILE__ );
define( 'MAINTAINER_PLUGIN_DIR', trailingslashit( dirname( MAINTAINER_FILE ) ) );
define( 'MAINTAINER_PLUGIN_URL', trailingslashit( plugin_dir_url( MAINTAINER_FILE ) ) );
define( 'MAINTAINER_PLUGIN_BASE', plugin_basename( MAINTAINER_FILE ) );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-activator.php
 */
register_activation_hook(
	__FILE__,
	function () {
		Activator::run();
	}
);

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-deactivator.php
 */
register_deactivation_hook(
	__FILE__,
	function () {
		Deactivator::run();
	}
);

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
add_action(
	'plugins_loaded',
	function () {
		Internalization::load();
		Init::instance();

		SubscriptionManagerFactory::create(
			array(
				'plugin_slug'            => 'maintainer',
				'plugin_name'            => 'Maintainer',
				'after_subscription_url' => admin_url( 'admin.php?page=maintainer' ),
				'version'                => MAINTAINER_VERSION,
				'branding'               => array(
					'logo'                => MAINTAINER_PLUGIN_URL . 'assets/images/icon.svg',
					'logo_width'          => '56px',
					'heading'             => 'Thank you for installing Maintainer!',
					'description'         => 'Join our email list for updates on security and new features! Providing a few details about your WordPress setup will help us optimize the plugin specifically for your site.',
					'button_color'        => '#059669',
					'button_hover_color'  => '#047857',
					'privacy_url'         => 'https://matterwp.com/privacy-policy/',
					'terms_url'           => 'https://matterwp.com/terms-of-service/',
					'button_text'         => 'Proceed & Go to Settings',
					'button_loading_text' => 'Processing...',
					'button_success_text' => 'Subscribed successfully',
				),
			)
		);
	}
);