<?php
/**
 * Helpers class
 *
 * This class is responsible for providing helper functions.
 *
 * @package Maintainer
 * @subpackage Core
 * @since 1.0.0
 */
namespace Maintainer\Core;

final class Helpers {

	/**
	 * Image directory
	 *
	 * @var string
	 */
	private static $image_dir = MAINTAINER_PLUGIN_URL . 'assets/admin/images/';

	/**
	 * Get template
	 *
	 * @param string $file The file name.
	 * @param string $type The type of template.
	 *
	 * @return string
	 */
	public static function get_template( $file, $type = 'admin' ) {
		$file = MAINTAINER_PLUGIN_DIR . 'templates/' . $type . '/' . $file . '.php';
		if ( file_exists( $file ) ) {
			include_once $file;
		}
		return '';
	}

	/**
	 * Get image
	 *
	 * @param string $image The image name with extension (e.g., 'logo.png')
	 * @param string $type The type of output ('url' or 'img')
	 * @param array  $attributes Optional HTML attributes for the img tag
	 * @return string
	 */
	public static function get_image( $image, $type = 'url', $attributes = array() ) {
		$image_path = self::$image_dir . $image;

		if ( $type === 'url' ) {
			return esc_url( $image_path );
		}

		// Build attributes string
		$attr_string = '';
		foreach ( $attributes as $key => $value ) {
			$attr_string .= ' ' . esc_attr( $key ) . '="' . esc_attr( $value ) . '"';
		}

		return sprintf( '<img src="%s"%s>', esc_url( $image_path ), $attr_string );
	}
}
