<?php
/**
 * Settings page template
 *
 * @package Maintainer
 * @since 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Maintainer\Core\Helpers;

// Retrieve options
$maintainer_active           = get_option( 'maintainer_active' );
$maintainer_primary_text     = get_option( 'maintainer_primary_text' );
$maintainer_secondary_text   = get_option( 'maintainer_secondary_text' );
$maintainer_page_title       = get_option( 'maintainer_page_title' );
$maintainer_page_description = get_option( 'maintainer_page_description' );
$maintainer_background_color = get_option( 'maintainer_background_color' );
$maintainer_text_color       = get_option( 'maintainer_text_color' );
$maintainer_ips              = (array) get_option( 'maintainer_ips', array() );
$maintainer_roles            = (array) get_option( 'maintainer_roles', array() );
$maintainer_query            = get_option( 'maintainer_query' );
$maintainer_noindex          = get_option( 'maintainer_noindex' );
$maintainer_template         = get_option( 'maintainer_template', 'dark' );
?>

<div id="maintainer-settings">
	<header>
		<div class="maintainer-brand">
			<svg width="20" height="22" viewBox="0 0 20 22" fill="none" xmlns="http://www.w3.org/2000/svg">
				<path d="M8.41989 0.380201L1.40155 4.45861L1.39943 4.46075C0.973693 4.71097 0.620382 5.06975 0.374807 5.50124C0.129231 5.93272 -7.00508e-06 6.42181 9.42109e-06 6.9196V15.0796C-0.00126823 15.5778 0.127427 16.0676 0.373119 16.4994C0.618811 16.9313 0.972813 17.2901 1.39943 17.5396L1.40261 17.5417L8.41883 21.619H8.42095C8.84659 21.8686 9.32991 22 9.82196 22C10.314 22 10.7973 21.8686 11.223 21.619H11.224L18.2403 17.5406H18.2434C18.6696 17.2901 19.0233 16.9309 19.2689 16.4988C19.5145 16.0667 19.6434 15.5769 19.6429 15.0786V6.92175C19.6431 6.42377 19.5139 5.93447 19.2683 5.50277C19.0227 5.07108 18.6693 4.71213 18.2434 4.46183L11.2251 0.383421L11.223 0.381274C10.7972 0.131535 10.3137 0 9.82143 0C9.32917 0 8.84566 0.130461 8.41989 0.380201ZM6.37066 11.0002C6.37066 10.0751 6.73423 9.18784 7.38137 8.53369C8.02852 7.87954 8.90623 7.51205 9.82143 7.51205C10.7366 7.51205 11.6144 7.87954 12.2615 8.53369C12.9086 9.18784 13.2722 10.0751 13.2722 11.0002C13.2722 11.9253 12.9086 12.8125 12.2615 13.4666C11.6144 14.1208 10.7366 14.4883 9.82143 14.4883C8.90623 14.4883 8.02852 14.1208 7.38137 13.4666C6.73423 12.8125 6.37066 11.9253 6.37066 11.0002Z" fill="#059669" />
			</svg>

			<span><?php echo esc_html( 'Maintainer' ); ?></span>

		</div>
		<div class="maintainer-version">
			<span>v<?php echo esc_html( MAINTAINER_VERSION ); ?></span>
		</div>
	</header>

	<div class="maintainer-options">
		<div class="maintainer-option-nav">
			<div class="maintainer-nav-items">
				<div class="mnav-item active" data-trigger="main">
					<?php esc_html_e( 'Main', 'maintainer' ); ?>
				</div>
				<div class="mnav-item" data-trigger="content">
					<?php esc_html_e( 'Content', 'maintainer' ); ?>
				</div>
				<div class="mnav-item" data-trigger="appearence">
					<?php esc_html_e( 'Appearence', 'maintainer' ); ?>
				</div>
				<div class="mnav-item" data-trigger="seo">
					<?php esc_html_e( 'SEO', 'maintainer' ); ?>
				</div>
				<div class="mnav-item" data-trigger="access">
					<?php esc_html_e( 'Access', 'maintainer' ); ?>
				</div>
			</div>
		</div>

		<form class="maintainer-options-group" method="post">
			<?php wp_nonce_field( 'maintainer_settings_save', 'maintainer_settings_nonce' ); ?>

			<div class="maintainer-option-group" data-id="main">
				<div class="m-option-group-title"><?php esc_html_e( 'Main Settings', 'maintainer' ); ?></div>
				<div class="m-options-holder">
					<div class="m-option">
						<div class="m-option-info">
							<div class="m-option-title"><?php esc_html_e( 'Maintenance Mode', 'maintainer' ); ?></div>
							<div class="m-option-description"><?php esc_html_e( 'Activate or deactivate the maintenance mode.', 'maintainer' ); ?></div>
						</div>
						<div class="m-option-input">
							<label class="switch">
								<input name="maintainer-active" type="checkbox" <?php checked( $maintainer_active, true ); ?>>
								<span class="slider round"></span>
							</label>
						</div>
					</div>


				</div>
			</div>

			<div class="maintainer-option-group" data-id="seo">
				<div class="m-option-group-title"><?php esc_html_e( 'SEO Settings', 'maintainer' ); ?></div>
				<div class="m-options-holder">
					<div class="m-option">
						<div class="m-option-info">
							<div class="m-option-title"><?php esc_html_e( 'Page Title', 'maintainer' ); ?></div>
							<div class="m-option-description"><?php esc_html_e( 'Set the page title for SEO purposes.', 'maintainer' ); ?></div>
						</div>
						<div class="m-option-input">
							<input name="maintainer-page-title" type="text" value="<?php echo esc_attr( $maintainer_page_title ); ?>">
						</div>
					</div>

					<div class="m-option">
						<div class="m-option-info">
							<div class="m-option-title"><?php esc_html_e( 'Page Description', 'maintainer' ); ?></div>
							<div class="m-option-description"><?php esc_html_e( 'Set the page description for SEO purposes.', 'maintainer' ); ?></div>
						</div>
						<div class="m-option-input">
							<input name="maintainer-page-description" type="text" value="<?php echo esc_attr( $maintainer_page_description ); ?>">
						</div>
					</div>

					<div class="m-option">
						<div class="m-option-info">
							<div class="m-option-title"><?php esc_html_e( 'No-index', 'maintainer' ); ?></div>
							<div class="m-option-description"><?php esc_html_e( 'Enable no-index meta tag on maintenance page.', 'maintainer' ); ?></div>
						</div>
						<div class="m-option-input">
							<label class="switch">
								<input name="maintainer-noindex" type="checkbox" <?php checked( $maintainer_noindex, true ); ?>>
								<span class="slider round"></span>
							</label>
						</div>
					</div>
				</div>
			</div>

			<div class="maintainer-option-group" data-id="content">
				<div class="m-option-group-title"><?php esc_html_e( 'Appearance', 'maintainer' ); ?></div>
				<div class="m-options-holder">
					<div class="m-option full-width">
						<div class="m-option-info">
							<div class="m-option-title"><?php esc_html_e( 'Maintenance Headline', 'maintainer' ); ?></div>
							<div class="m-option-description"><?php esc_html_e( 'Set the primary text for the maintenance page.', 'maintainer' ); ?></div>
						</div>
						<div class="m-option-input">
							<input name="maintainer-primary-text" type="text" value="<?php echo esc_attr( $maintainer_primary_text ); ?>">
						</div>
					</div>

					<div class="m-option full-width">
						<div class="m-option-info">
							<div class="m-option-title"><?php esc_html_e( 'Maintenance Text', 'maintainer' ); ?></div>
							<div class="m-option-description"><?php esc_html_e( 'Set the secondary text for the maintenance page.', 'maintainer' ); ?></div>
						</div>
						<div class="m-option-input">
							<?php
								$editor_settings = array(
									'textarea_name' => 'maintainer-secondary-text',
									'textarea_rows' => 3,
									'media_buttons' => true,
									'teeny'         => false,
									'editor_height' => 200,
									'tinymce'       => array(
										'toolbar1'         => 'bold,italic,bullist,numlist,wp_more,spellchecker,fullscreen,wp_adv',
										'toolbar2'         => 'strikethrough,hr,forecolor,pastetext,removeformat,charmap,outdent,indent,undo,redo,wp_help',
										'content_style'    => 'body#tinymce.wp-editor { max-width: 100%; margin: 0 12px; background: #fff; color: #333; font-family: -apple-system, Roboto, Oxygen-Sans, Ubuntu, Cantarell, sans-serif; font-size: 13px; line-height: 1.5; }',
										'wpautop'          => true,
										'force_br_newlines' => false,
										'force_p_newlines' => true,
										'forced_root_block' => 'p',
										'plugins'          => 'charmap,colorpicker,hr,lists,media,paste,tabfocus,textcolor,fullscreen,wordpress,wpautoresize,wpeditimage,wpemoji,wpgallery,wplink,wpdialogs,wptextpattern,wpview',
									),
									'quicktags'     => array(
										'buttons' => 'strong,em,link,block,del,ins,img,ul,ol,li,code,more,close',
									),
									'wpautop'       => true,
								);

								wp_editor(
									wp_kses_post( $maintainer_secondary_text ),
									'maintainer-secondary-text',
									$editor_settings
								);
								?>
						</div>
					</div>
				</div>
			</div>


			<div class="maintainer-option-group" data-id="appearence">
				<div class="m-option-group-title"><?php esc_html_e( 'Appearance', 'maintainer' ); ?></div>
				<div class="m-options-holder">

					<div class="m-option full-width">
						<div class="m-option-info">
							<div class="m-option-title"><?php esc_html_e( 'Color Scheme', 'maintainer' ); ?></div>
							<div class="m-option-description"><?php esc_html_e( 'Choose the schema for the maintenance page.', 'maintainer' ); ?></div>
						</div>
						<div class="m-option-input">
							<div class="m-templates">
								<?php
								$templates = array(
									'white',
									'gray',
									'black',
									'dark',
									'red',
									'orange',
									'amber',
									'yellow',
									'lime',
									'green',
									'emerald',
									'teal',
									'cyan',
									'sky',
									'blue',
									'indigo',
									'violet',
									'purple',
									'pink',
									'rose',
								);
								foreach ( $templates as $template ) :
									?>
								<label>
									<input type="radio" name="maintainer-template" value="<?php echo esc_attr( $template ); ?>" <?php checked( $maintainer_template, $template ); ?>>
									<div class="color-box color-box--<?php echo esc_attr( $template ); ?>">
										<div class="color-box-content">
											<div class="color-box-title"><?php echo esc_html( 'Coming Soon' ); ?></div>
											<div class="color-box-description"><?php echo esc_html( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nullam imperdiet.' ); ?></div>
										</div>
									</div>
									<div class="color-box-name"><?php echo esc_html( ucfirst( $template ) ); ?></div>
								</label>
								<?php endforeach; ?>
							</div>
						</div>
					</div>

				</div>
			</div>

			<div class="maintainer-option-group" data-id="access">
				<div class="m-option-group-title"><?php esc_html_e( 'Access Settings', 'maintainer' ); ?></div>
				<div class="m-options-holder">
					<div class="m-option top">
						<div class="m-option-info">
							<div class="m-option-title"><?php esc_html_e( 'Allowed Roles', 'maintainer' ); ?></div>
							<div class="m-option-description"><?php esc_html_e( 'Select roles allowed to bypass maintenance mode.', 'maintainer' ); ?></div>
						</div>
						<div class="m-option-input">
							<div class="role-checkboxes">
								<?php
								$wp_roles  = wp_roles();
								$all_roles = $wp_roles->get_names();
								foreach ( $all_roles as $role_key => $role_name ) :
									?>
								<label class="role-checkbox">
									<input type="checkbox" name="maintainer-allowed-roles[]" value="<?php echo esc_attr( $role_key ); ?>" <?php checked( in_array( $role_key, $maintainer_roles, true ), true ); ?>>
									<span class="checkmark"></span>
									<?php echo esc_html( $role_name ); ?>
								</label>
								<?php endforeach; ?>
							</div>
						</div>
					</div>

					<div class="m-option">
						<div class="m-option-info">
							<div class="m-option-title"><?php esc_html_e( 'Allowed IPs', 'maintainer' ); ?></div>
							<div class="m-option-description">
								<?php
								printf(
									/* translators: %1$s: IP format example */
									esc_html__( 'Add IP addresses that can access the site during maintenance mode. One IP per line. Example: %1$s', 'maintainer' ),
									'<code>192.168.1.1</code>'
								);
								?>
							</div>
						</div>
						<div class="m-option-input">
							<textarea name="maintainer-ips"><?php echo esc_textarea( implode( "\n", $maintainer_ips ) ); ?></textarea>
						</div>
					</div>

					<div class="m-option">
						<div class="m-option-info">
							<div class="m-option-title"><?php esc_html_e( 'Query Parameter', 'maintainer' ); ?></div>
							<div class="m-option-description">
								<?php
								printf(
									/* translators: %1$s: example URL with parameter */
									esc_html__( 'Set a bypass parameter to access your site while maintenance mode is active. Example: %1$s. Useful for testing or allowing access to third-party services.', 'maintainer' ),
									'<code>yoursite.com/?mp=yourparameter</code>'
								);
								?>
							</div>
						</div>
						<div class="m-option-input">
							<input type="text" name="maintainer-query" value="<?php echo esc_attr( $maintainer_query ); ?>">
						</div>
					</div>
				</div>
			</div>

			<div class="maintainer-save">
				<div class="maintainer-notice-wrapper">

				</div>
				<button class="save"><?php esc_html_e( 'Save', 'maintainer' ); ?></button>
			</div>

		</form>
	</div>
</div>