<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

$maintainer_primary_text     = get_option( 'maintainer_primary_text' );
$maintainer_secondary_text   = get_option( 'maintainer_secondary_text' );
$maintainer_page_title       = get_option( 'maintainer_page_title' ) ? get_option( 'maintainer_page_title' ) : 'Coming Soon';
$maintainer_page_description = get_option( 'maintainer_page_description' );
$maintainer_template         = get_option( 'maintainer_template' );
$current_ip                  = isset( $_SERVER['REMOTE_ADDR'] ) ? sanitize_text_field( wp_unslash( $_SERVER['REMOTE_ADDR'] ) ) : '';
$maintainer_noindex          = get_option( 'maintainer_noindex', true );
?>

<!DOCTYPE html>
<html>

	<head>
		<meta charset="utf-8">
		<meta http-equiv="X-UA-Compatible" content="IE=edge">
		<title><?php echo esc_html( $maintainer_page_title ); ?></title>
		<?php if ( $maintainer_page_description ) : ?>
		<meta name="description" content="<?php echo esc_html( $maintainer_page_description ); ?>">
		<?php endif; ?>

		<?php if ( $maintainer_noindex ) : ?>
		<meta name="robots" content="noindex,nofollow">
		<?php endif; ?>

		<meta name="viewport" content="width=device-width, initial-scale=1">

		<?php \wp_head(); ?>
	</head>

	<body class="maintainer <?php echo esc_attr( 'maintainer--' . MAINTAINER_VERSION ); ?> <?php echo esc_attr( 'template--' . $maintainer_template ); ?>">
		<div class="container">
			<h1><?php echo esc_html( $maintainer_primary_text ); ?></h1>

			<?php if ( $maintainer_secondary_text ) : ?>
			<div class="maintainer-secondary-text">
				<?php
				$allowed_html = array(
					'a'      => array(
						'href'   => array(),
						'title'  => array(),
						'target' => array(),
						'rel'    => array(),
						'class'  => array(),
					),
					'br'     => array(),
					'em'     => array(),
					'strong' => array(),
					'p'      => array(
						'class' => array(),
					),
					'span'   => array(
						'class' => array(),
					),
					'div'    => array(
						'class' => array(),
					),
				);
				echo wpautop( wp_kses( $maintainer_secondary_text, $allowed_html ) );
				?>
			</div>
			<?php endif; ?>

			<div class="maintainer-ip"><?php echo esc_html( 'Your IP Address: ' . $current_ip ); ?></div>
		</div>
	</body>

</html>